@@ -72,4 +72,19 @@ def remove_leading_whitespaces(sentence: str) -> str:
 	'''Remove all leading whitespaces from sentence.
 	- remove_leading_whitespaces("   text") -> "text"
 	- remove_leading_whitespaces(" Look at this.") -> "Look at this."'''
-	return re.sub(r"^\s+", '', sentence)
\ No newline at end of file
+	return re.sub(r"^\s+", '', sentence)
+
+def text_to_binary(sentence: str) -> str:
+	'''Convert string to a binary (A binary number is a number expressed in the base-2 numeral system or binary numeral system,
+	a method of mathematical expression which uses only two symbols: 0 and 1)
+	- text_to_binary("Hello") -> 0100100001100101011011000110110001101111
+	- text_to_binary("A") -> 01000001'''
+	# 08 means width 8, 0 padded, and the b functions as a sign to output the resulting number in base 2 (binary).
+	return "".join(f"{ord(char):08b}" for char in sentence)
+
+def binary_to_text(binary: str) -> str:
+	'''Convert binary to text (A binary number is a number expressed in the base-2 numeral system or binary numeral system,
+	a method of mathematical expression which uses only two symbols: 0 and 1)
+	- binary_to_text("0100100001100101011011000110110001101111") -> "Hello"
+	- binary_to_text("01000001") -> "A"'''
+	return ''.join(chr(int(binary[i*8:i*8+8],2)) for i in range(len(binary)//8))
